==> tlmpweb-1.14.src.tar.gz: tlmpweb-1.14/tlmpweb/tlmpwebcc.cc <==
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <errno.h>

#define TLMPWEB_VERSION	"1.0"

static void usage()
{
	fprintf (stderr,"tlmpwebcc version %s\n",TLMPWEB_VERSION);
}

static void tlmpwebcc_html (FILE *fout, const char *s)
{
	fprintf (fout,"fputs (\"");
	while (*s != '\0'){
		if (*s == '"'){
			//fputc ('\\',fout);
			fputc ('\\',fout);
			fputc ('"',fout);
		}else{
			fputc (*s,fout);
		}
		s++;
	}
	fprintf (fout,"\\n\",stdout);\n");
}

int main (int argc, char *argv[])
{
	int ret = -1;
	if (argc  != 3 && argc != 2){
		usage();
		ret = -1;
	}else{
		FILE *fin = fopen (argv[1],"r");
		if (fin == NULL){
			fprintf (stderr,"Can't open file %s (%s)\n",argv[1]
				,strerror(errno));
		}else{
			FILE *fout = stdout;
			if (argc == 3) fout = fopen (argv[2],"w");
			if (fout == NULL){
				fprintf (stderr,"Can't open file %s (%s)\n",argv[2]
					,strerror(errno));
			}else{
				// fprintf (fout,"#include <stdio.h>\n");
				char buf[1000];
				bool html = false;
				while (fgets(buf,sizeof(buf)-1,fin)!=NULL){
					int last = strlen(buf)-1;
					if (last >= 0 && buf[last] == '\n') buf[last] = '\0';
					char *start = buf;
					char *pt = start;
					while (isspace (*pt))pt++;
					if (pt[0] == '\0'){
						fprintf (fout,"%s\n",start);
						continue;
					}
					while (*start != '\0'){
						if (html){
							char *pt = strstr (start,"?>");
							if (pt != NULL){
								*pt = '\0';
								tlmpwebcc_html (fout,start);
								start = pt + 2;
								html = false;
							}else{
								pt = strstr (start,"/-");
								if (pt != NULL){
									*pt = '\0';
									tlmpwebcc_html (fout,start);
									fputs (pt+2,fout);
								}else{
									tlmpwebcc_html (fout,start);
								}
								start = "";
							}
						}else{
							char *pt = strstr (start,"<?");
							if (pt != NULL){
								*pt = '\0';
								fputs (start,fout);
								fputc ('\n',fout);
								start = pt + 2;
								html = true;
							}else{
								pt = strstr (start,"/-");
								if (pt != NULL){
									*pt = '\0';
									fputs (start,fout);
									tlmpwebcc_html (fout,pt+2);
								}else{
									fputs (start,fout);
									fputc ('\n',fout);
								}
								start = "";
							}
						}
					}
				}
				if (fout != stdout) ret = fclose (fout);
			}
			fclose (fin);
		}
	}
	return ret;
}

==> tlmpweb-1.22.src.tar.gz: tlmpweb-1.22/tlmpweb/tlmpwebcc.cc <==
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <errno.h>

static void usage()
{
	fprintf (stderr,"tlmpwebcc version %s.%d\n",TLMPWEB_VERSION,TLMPWEB_RELEASE);
}

static char *str_skip (const char *s)
{
	while (isspace(*s)) s++;
	return (char*)s;
}

static void tlmpwebcc_html (FILE *fout, const char *s)
{
	fprintf (fout,"fputs (\"");
	while (*s != '\0'){
		if (*s == '"'){
			//fputc ('\\',fout);
			fputc ('\\',fout);
			fputc ('"',fout);
		}else{
			fputc (*s,fout);
		}
		s++;
	}
	fprintf (fout,"\\n\",stdout);\n");
}

int main (int argc, char *argv[])
{
	int ret = -1;
	if (argc  != 3 && argc != 2){
		usage();
		ret = -1;
	}else{
		FILE *fin = fopen (argv[1],"r");
		if (fin == NULL){
			fprintf (stderr,"Can't open file %s (%s)\n",argv[1]
				,strerror(errno));
		}else{
			FILE *fout = stdout;
			if (argc == 3) fout = fopen (argv[2],"w");
			if (fout == NULL){
				fprintf (stderr,"Can't open file %s (%s)\n",argv[2]
					,strerror(errno));
			}else{
				// fprintf (fout,"#include <stdio.h>\n");
				char buf[1000];
				bool html = false;
				bool c_seen = false;	// The last line in an HTML
										// section was a C++ statement
				while (fgets(buf,sizeof(buf)-1,fin)!=NULL){
					int last = strlen(buf)-1;
					if (last >= 0 && buf[last] == '\n') buf[last] = '\0';
					char *start = buf;
					char *pt = start;
					while (isspace (*pt))pt++;
					if (pt[0] == '\0'){
						fprintf (fout,"%s\n",start);
						continue;
					}
					while (*start != '\0'){
						if (html){
							char *pt = strstr (start,"?>");
							if (pt != NULL){
								*pt = '\0';
								tlmpwebcc_html (fout,start);
								start = pt + 2;
								html = false;
								c_seen = false;
							}else{
								pt = strstr (start,"/-");
								if (pt != NULL){
									*pt = '\0';
									if (c_seen){
										const char *end = str_skip(start);
										if (*end != '\0'){
											tlmpwebcc_html (fout,start);
										}
									}else{
										tlmpwebcc_html (fout,start);
									}
									fputs (pt+2,fout);
									c_seen = true;
								}else{
									tlmpwebcc_html (fout,start);
									c_seen = false;
								}
								start = "";
							}
						}else{
							char *pt = strstr (start,"<?");
							if (pt != NULL){
								*pt = '\0';
								fputs (start,fout);
								fputc ('\n',fout);
								start = pt + 2;
								html = true;
							}else{
								pt = strstr (start,"/-");
								if (pt != NULL){
									*pt = '\0';
									fputs (start,fout);
									tlmpwebcc_html (fout,pt+2);
								}else{
									fputs (start,fout);
									fputc ('\n',fout);
								}
								start = "";
							}
						}
					}
				}
				if (fout != stdout) ret = fclose (fout);
			}
			fclose (fin);
		}
	}
	return ret;
}
